/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 4: 	Relationship between aging and the adoption
			of industrial robots
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/figure_robots_aging.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

***Program that defines the plot-style ***
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string) name(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	reg `y_vars' `x_var' `controls'  `wt'  `if', r
	local beta: di %3.2f  _b[`x_var']
	local tstat: di %3.2f _b[`x_var']/_se[`x_var']
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	
	*Residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<1 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<5 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<1 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<3 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: replace `tag_label'=1 if country_name=="united states"
	quietly: replace `tag_label'=1 if country_name=="finland"
	
	
	tempvar labvar
	gen `labvar'=upper(country_name)
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=.,  color(dkorange) msize(*1)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mlabel(`labvar') mlabposition(7) mlabcolor(navy) msize(*0)), ///
		   ylabel(, noticks angle(horizontal)) legend(off) xtitle("`xtitle'", size(large) ) ytitle("") title("`ytitle'", position(11)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(4) xsize(7) name("`name'", replace)
   
end

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

* names in figures *
replace country_name="hong kong" if country_name=="china,hong kong s.a.r."
replace country_name="china" if country_name=="china p.rep."

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

**********************************************
********Left Panel of Figure 4****************
**********************************************
resid_plot change_robots change_dependency if full_sample==1, ///
           control(i.dreg $country_covariates) ///
		   xtitle("Aging between 1990 and 2025") ytitle(`"Annual increase in robots" "between 1993 and 2014---all countries"') ///
		   name("full_sample")

**********************************************
********Right Panel of Figure 4***************
**********************************************		   
resid_plot change_robots change_dependency if new_region=="OECD", ///
           control($country_covariates) ///
		   xtitle("Aging between 1990 and 2025") ytitle(`"Annual increase in robots" "between 1993 and 2014---OECD"') ///
		   name("oecd_sample")		   
		   
gr combine full_sample oecd_sample, graphregion(color(white)) xsize(8) cols(2) 
graph export "$project/results/figure_robots_aging.pdf", as(pdf) replace		   
		   
