/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure A2: 	Scatter plots in growth rates
			
Notes: 		
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/4/2021
			
Output: 	/results/figure_robots_logs.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

***Program that defines the plot-style ***
cap program drop resid_plot
program define resid_plot, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) xtitle(string) ytitle(string) name(string)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	
	reg `y_vars' `x_var' `controls'  `wt'  `if', r
	local beta: di %3.2f  _b[`x_var']
	local tstat: di %3.2f _b[`x_var']/_se[`x_var']
	tempvar est_sample
	tempvar residual_y
	tempvar projected_y
	quietly: gen `est_sample'=e(sample)
	quietly: predict `residual_y' if `est_sample'==1, resid
	quietly: sum `y_vars' if e(sample) `wt'
	quietly: gen `projected_y'=`residual_y'+r(mean)
	quietly: sum `x_var' if e(sample) `wt'
	quietly: replace `projected_y'=`projected_y'+_b[`x_var']*(`x_var'-r(mean))
	
	
	
	*Define set of markers to label*
	tempvar tag_label
	tempvar tag_rank
	quietly: gen `tag_label'=0
	
	*Residuals*
	quietly: egen `tag_rank'=rank(`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<5 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`residual_y') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<5 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Yvar*
	quietly: egen `tag_rank'=rank(`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<3 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`y_vars') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	*Xvar*
	quietly: egen `tag_rank'=rank(`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<3 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: egen `tag_rank'=rank(-`x_var') if `residual_y'!=., track
	quietly: replace `tag_label'=1 if `tag_rank'<4 & `residual_y'!=.
	quietly: drop `tag_rank'
	
	quietly: replace `tag_label'=1 if country_name=="united states"
	quietly: replace `tag_label'=1 if country_name=="finland"
	
	
	tempvar labvar
	gen `labvar'=upper(country_name)
	
	twoway (scatter `projected_y' `x_var' `wt' if `projected_y'!=.,  color(dkorange) msize(*1)) ///
		   (lfit    `projected_y' `x_var' `wt' if `projected_y'!=., lcolor(navy) lwidth(thin)) ///
		   (scatter `projected_y' `x_var' if `tag_label'==1, mlabel(`labvar')  mlabcolor(navy) mlabpos(12) msize(*0)), ///
		   ylabel(, noticks angle(horizontal)) legend(off) xtitle("`xtitle'", size(large)) ytitle("") title("`ytitle'", position(11)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(4) xsize(7) name("`name'", replace)
   
end


* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 

* names in figures *
replace country_name="hong kong" if country_name=="china,hong kong s.a.r."
replace country_name="china" if country_name=="china p.rep."


*robot variables: log(x) specification*
gen base1993_stock_pc=ln(stock_robots_1993/$normalization_robots)
gen change_robots=ln(stock_robots_2014/$normalization_robots )-ln(stock_robots_1993/$normalization_robots )

*******************************************
**Figure, log(x), left Panel of Figure A2**
*******************************************
resid_plot change_robots change_dependency, control( base1993_stock_pc $country_covariates) xtitle("Aging between 1990 and 2025") ytitle("Percent increase in robots 1993--2014") name(log)

*robot variables: log(1+x) specification*
cap drop base1993* change_robots
gen base1993_zero=(stock_robots_1993>0)
gen base1993_stock_pc=ln((stock_robots_1993+1)/$normalization_robots)
gen change_robots=ln((stock_robots_2014+1)/$normalization_robots )-ln((stock_robots_1993+1)/$normalization_robots )
quietly: reg change_robots change_dependency base1993_stock_pc i.dreg $country_covariates
gen new_sample=e(sample)

**********************************************
**Figure, log(1+x), right Panel of Figure A2**
**********************************************
resid_plot change_robots change_dependency, control(base1993_stock_pc $country_covariates i.dreg) xtitle("Aging between 1990 and 2025") ytitle("Percent increase in robots 1993--2014") name(logone)

* combine figures *
gr combine log logone, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) xsize(8) cols(2) 
graph export "$project/results/figure_robots_logs.pdf", as(pdf) replace	
