/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 2: 	Estimates of the impact of aging on the adoption of 
			industrial robots
			
Notes: 		1. Expanded to include columns 4 and 8 following requests
			by referees (7/16/2020)
			2. The dummy "main_sample" restricts regressions to the
			sample used in 2019 version. The sample was expanded with
			new ILO data on industry employment.
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_aging_ols.tex
			/results/table_aging_ols_weighted.tex
			/results/table_aging_iv.tex
			/results/table_aging_iv_weighted.tex
			/results/table_aging_single_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

* human capital and schooling *
gen change_hc  =(bl_all_full_college2010-bl_all_full_college1990)/100 /* change in human capital from BL dataset, 1990--2010 (note: no data after 2010) */
gen change_flfp=(flfp_prime2015-flfp_prime1990)/100                   /* change in relative female labor force participation, 1990--2015 */

*Unions: combine Rama dataset and ICTWSS*
gen union_density=rama_unions_85
replace union_density=ictwss_unions_90s if union_density==.
replace union_density=union_density/100

* sample selection: countries with robot data and full covariates, excluding Japan and Russia *
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************	
************************Table 2, Panel A: OLS models, unweighted ************************
*****************************************************************************************
reg change_robots 	change_dependency i.dreg if full_sample, r
estimates store e1

* computing partial r-square reported in the paper *
reg change_robots i.dreg if full_sample
predict change_y, resid
reg change_dep i.dreg if full_sample
predict change_x, resid
reg change_y change_x if full_sample, r


reg change_robots 	change_dependency i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg change_robots 	change_dependency change_hc change_flfp  ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e4

reg change_robots 	change_dependency if new_region=="OECD", r
estimates store e5

reg change_robots 	change_dependency $country_covariates  if new_region=="OECD", r
estimates store e6

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD", r
estimates store e7

reg change_robots 	change_dependency change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD", r
estimates store e8

* export table *
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_aging_ols.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  change_hc             "Increase in schooling 1990--2010" ///
		  change_flfp           "Change in relative FLFP 1990--2015") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_hc change_flfp) ///
order(change_dependency change_hc change_flfp) 

************************************************************************************************************************
************************Table 2,  Panel D: OLS models, weighted by value added in manufacturing ************************
************************************************************************************************************************
reg change_robots 	change_dependency i.dreg if full_sample  $robot_weight, r
estimates store e1

reg change_robots 	change_dependency i.dreg $country_covariates if full_sample  $robot_weight, r
estimates store e2

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample  $robot_weight, r
estimates store e3

reg change_robots 	change_dependency change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample  $robot_weight, r
estimates store e4

reg change_robots 	change_dependency if new_region=="OECD"  $robot_weight, r
estimates store e5

reg change_robots 	change_dependency $country_covariates  if new_region=="OECD"  $robot_weight, r
estimates store e6

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD"  $robot_weight, r
estimates store e7

reg change_robots 	change_dependency change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD"  $robot_weight, r
estimates store e8

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_aging_ols_weighted.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency)

*******************************************************************************************************
************************Table 2, Panel B: IV estimates using 5-year birthrates ************************
*******************************************************************************************************
ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg if full_sample, r ffirst partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg $country_covariates if full_sample, r ffirst partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r ffirst partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=$instruments ) change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r ffirst partial(i.dreg)
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments ) if new_region=="OECD", r ffirst 
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments ) $country_covariates if new_region=="OECD", r ffirst 
estimates store e6

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r ffirst 
estimates store e7

ivreg2 change_robots 	(change_dependency=$instruments ) change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r ffirst 
estimates store e8

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_aging_iv.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)

*********************************************************************************************************************
************************Table 2, Panel E: IV models weighted by value added in manufacturing ************************
*********************************************************************************************************************
ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg if full_sample $robot_weight, r ffirst partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments ) i.dreg $country_covariates if full_sample $robot_weight, r ffirst partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r ffirst partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=$instruments ) change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r ffirst partial(i.dreg)
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments ) if new_region=="OECD" $robot_weight, r ffirst 
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments ) $country_covariates if new_region=="OECD" $robot_weight, r ffirst 
estimates store e6

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" $robot_weight, r ffirst 
estimates store e7

ivreg2 change_robots 	(change_dependency=$instruments ) change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" $robot_weight, r ffirst 
estimates store e8

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_aging_iv_weighted.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)

***********************************************************************************************************************************
************************Table 2, Panel C: IV estimates exploiting decline in birthrates between 1960--1980 ************************
***********************************************************************************************************************************

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) i.dreg if full_sample, r partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) i.dreg $country_covariates if full_sample, r partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r partial(i.dreg)
estimates store e4

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) if new_region=="OECD", r 
estimates store e5

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) $country_covariates if new_region=="OECD", r 
estimates store e6

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r 
estimates store e7

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r 
estimates store e8

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_aging_single_iv.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025"   ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat."  )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)

***********************************************************************************************************************************
************************Complementary exercises mentioned in the paper but not reported in tables         *************************
***********************************************************************************************************************************
tab dreg if full_sample==1, gen(dummies_region)

ivreg2 change_robots 	(change_dependency=$instruments ) $country_covariates i.dreg if full_sample, r liml partial(i.dreg)
condivreg change_robots 	(change_dependency=$instruments ) $country_covariates dummies_region1 dummies_region2 dummies_region3 dummies_region4 dummies_region6 if full_sample==1

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates i.dreg if full_sample, r liml partial(i.dreg)
condivreg change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates dummies_region1 dummies_region2 dummies_region3 dummies_region4 dummies_region6 if full_sample==1

ivreg2 change_robots 	(change_dependency=$instruments ) $country_covariates if new_region=="OECD", r liml
condivreg change_robots 	(change_dependency=$instruments ) $country_covariates  if new_region=="OECD"

ivreg2 change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r liml
condivreg change_robots 	(change_dependency=$instruments ) ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD", interval liml


