/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 4: 	Estimates of the impact of aging on imports and
			exports of industrial robots
			
Notes: 		1. This do-file analyses exports.
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_comtrade_exports_ols.tex			
			/results/table_comtrade_exports_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1996_2015.dta", assert(1 3) nogenerate
merge 1:1 isocode using "${project}/clean_data/comtrade_robots_1996_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*compute total imports of intermediate goods*
foreach flow in im_ ex_ re_{
egen intermediate_`flow'96=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile)
}
 
*sample selection: drop Nigeria---a large outlier*
drop if country_name=="nigeria"

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1995)

*regions*
encode new_region, gen(dreg)

*outcome: share divided by total intermediate imports going back to 1996, the year that robot imports became available*
drop if tv_ex_robots_orig<0
gen share_robots=ln(tv_ex_robots_orig/intermediate_ex_96)
gen ln_exports=ln(intermediate_ex_96)

*define sample*
quietly: reg share_robots  change_dependency  $country_covariates_1995  i.dreg  $exports_weights, r
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************
************************Table 4, Panel C: OLS models, weighted exports ******************
*****************************************************************************************
reg share_robots  change_dependency   i.dreg $exports_weights if full_sample, r
estimates store e1

* computing partial r-square reported in the paper *
reg share_robots i.dreg if full_sample $exports_weights
predict change_y, resid
reg change_dep i.dreg if full_sample $exports_weights
predict change_x, resid
reg change_y change_x if full_sample $exports_weights, r


reg share_robots  change_dependency   $country_covariates_1995  i.dreg $exports_weights if full_sample, r
estimates store e2

reg share_robots  change_dependency   ln_manuf_va ln_exports $country_covariates_1995  i.dreg $exports_weights if full_sample, r
estimates store e3

reg share_robots  change_dependency   $exports_weights if new_region=="OECD", r
estimates store e4

reg share_robots  change_dependency   $country_covariates_1995  $exports_weights if new_region=="OECD", r
estimates store e5

reg share_robots  change_dependency   ln_manuf_va ln_exports $country_covariates_1995  $exports_weights if new_region=="OECD", r
estimates store e6

estout e1 e2 e3 e4 e5 e6  using "$project/results/table_comtrade_exports_ols.tex", style(tex) ///
varlabels(change_dependency "Aging between 1995 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep( change_dependency ) ///
order(change_dependency ) 

*****************************************************************************************
************************Table 4, Panel D: IV models, weighted exports *******************
*****************************************************************************************
ivreg2 share_robots  (change_dependency=$instruments )   i.dreg $exports_weights if full_sample, r ffirst
estimates store e1

ivreg2 share_robots  (change_dependency=$instruments )   $country_covariates_1995  i.dreg $exports_weights if full_sample, r ffirst
estimates store e2

ivreg2 share_robots  (change_dependency=$instruments )   ln_manuf_va ln_exports $country_covariates_1995  i.dreg $exports_weights if full_sample, r ffirst
estimates store e3

ivreg2 share_robots  (change_dependency=$instruments )   $exports_weights if new_region=="OECD", r ffirst
estimates store e4

ivreg2 share_robots  (change_dependency=$instruments )   $country_covariates_1995  $exports_weights if new_region=="OECD", r ffirst
estimates store e5

ivreg2 share_robots  (change_dependency=$instruments )   ln_manuf_va ln_exports $country_covariates_1995  $exports_weights if new_region=="OECD", r ffirst
estimates store e6

estout e1 e2 e3 e4 e5 e6  using "$project/results/table_comtrade_exports_iv.tex", style(tex) ///
varlabels(change_dependency "Aging between 1995 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep( change_dependency  ) ///
order(change_dependency  ) 

