/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 6: 	Estimates of the impact of aging on the location
			of robot integrators in the US
			
Notes: 		1. uses data available in the replication kit of
            "Robots and Jobs: Evidence from US labor markets"
	        czones_integrators
	        czones_covariates_1990
	        czones_exposure_longdif
			2. the single IV within the US is the decline in birthrates 
			between 1950 and 1980. This matches the period of 
			fast birthrate decline for the country as a whole
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_integrators_ols.tex			
			/results/table_integrators_iv.tex
			/results/table_integrators_single_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
	
	**************************
	*******Housekeeping*******
	**************************

* data from R&J *
use "${project}/clean_data/czones_integrators.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/czones_covariates_1990.dta", assert(3) nogenerate

* additional controls and measures of aging *
merge 1:1 czone using "${project}/clean_data/czones_demographics.dta", assert(3) nogenerate

* define alternative instrument *
gen    single_iv=ln(brate1950)-ln(brate1980)
global instruments_czone brate*

* control variables *
gen nhgis_ln_gdp_1990=ln(nhgis_percapita_income_1990)
gen log_pop_1990=ln(population_1990)

* measures of aging: change in dependency ratio between 1990 and 2015 *
gen change_dep=${aging_measure}2015-${aging_measure}1990
gen base_dep=${aging_measure}1990

*groups of covariates and measure of exposure*
global demographics_cz        nhgis_male_share_1990 nhgis_urban_share_1990 base_dep nhgis_ln_gdp_1990 log_pop_1990 nhgis_edu_*1990 nhgis_race_*1990 
global other_shocks_cz        chinashock_iv_90_07 expo_share_occ_routine_1990 
global industry_shares_cz 	  nhgis_empsh_* 
global regional_dummies_cz    i.region

* dependent variable: dummy for location of integrators *
gen loc_integrator=dum_int

	************************
	*******Estimation*******
	************************ 
	
***********************************************************************************
************************Table 6, Panel A: Basic OLS********************************
***********************************************************************************

reg loc_integrator  change_dep $regional_dummies_cz , r cluster(state)
estimates store e1

*Basic demographic controls (same set used in cross country analysis)*
reg  loc_integrator change_dep $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e2

*Control for potential for automation and industry composition*
reg  loc_integrator change_dep expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz, r cluster(state)
estimates store e3

*Additional covariates*
reg  loc_integrator change_dep expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, r cluster(state)
estimates store e4

*Controlling for areas with high exposure, all cattered by integrators in detroit*
reg  loc_integrator change_dep expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz if tag_exposure==1, r cluster(state)
estimates store e5

*Export tables*
estout e1 e2 e3 e4 e5  using  "$project/results/table_integrators_ols.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
		  change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  expof_euro5_qo93_07) ///
order(change_dep expof_euro5_qo93_07)

**************************************************************************************
************************Table 6, Panel B: IV Estimates********************************
**************************************************************************************
ivreg2  loc_integrator (change_dep=$instruments_czone) $regional_dummies_cz, r cluster(state) ffirst
estimates store e1

*Basic demographic controls (same set used in cross country analysis)*
ivreg2  loc_integrator (change_dep=$instruments_czone) $demographics_cz $regional_dummies_cz, r cluster(state) ffirst
estimates store e2

*Control for potential for automation and industry composition*
ivreg2  loc_integrator (change_dep=$instruments_czone) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz, r cluster(state) ffirst
estimates store e3

*Additional covariates*
ivreg2  loc_integrator (change_dep=$instruments_czone) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, r cluster(state) ffirst
estimates store e4

*Remove areas with high exposure*
ivreg2  loc_integrator (change_dep=$instruments_czone) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz if tag_exposure==1, r cluster(state) ffirst
estimates store e5

*Export tables*
estout e1 e2 e3 e4 e5 using  "$project/results/table_integrators_iv.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
		  change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  expof_euro5_qo93_07) ///
order(change_dep expof_euro5_qo93_07)

**********************************************************************************************
************************Table 6, Panel C: Single-IV estimates ********************************
**********************************************************************************************
ivreg2  loc_integrator (change_dep=single_iv) $regional_dummies_cz, r cluster(state)
estimates store e1

*Basic demographic controls (same set used in cross country analysis)*
ivreg2  loc_integrator (change_dep=single_iv) $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e2

*Control for potential for automation and industry composition*
ivreg2  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz, r cluster(state)
estimates store e3

*Additional covariates*
ivreg2  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, r cluster(state)
estimates store e4

*Removing high exposure*
ivreg2  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz if tag_exposure==1, r cluster(state)
estimates store e5

*Export tables*
estout e1 e2 e3 e4 e5 using  "$project/results/table_integrators_single_iv.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
		  change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  expof_euro5_qo93_07) ///
order(change_dep expof_euro5_qo93_07)
