/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A10: 	Estimates of the impact of aging on the adoption of
			industrial robots controlling for the change
			in overall population
			
Notes: 		1. As requested by a referee, we added an extra model
			controlling for a traditional dependency ratio
			for population above 65 years of age
			2. This do-file generates unused tex files
			marked below.

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_change_pop_ols.tex
			/results/table_change_pop_ols_weighted.tex (unused)
			/results/table_change_pop_iv.tex
			/results/table_change_pop_iv_weighted.tex (unused)
			/results/table_change_pop_single_iv.tex
			/results/table_change_65_ols.tex
			/results/table_change_65_ols_weighted.tex (unused)

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}
gen change_65=(dependency_65_y2025-dependency_65_y1990)

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
gen change_pop=log_pwt_population2014-log_pwt_population1990

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************	
*****************Table A10, Panel A: OLS models, unweighted *****************************
*****************************************************************************************

reg change_robots 	change_dependency change_pop i.dreg if full_sample, r
estimates store e1

reg change_robots 	change_dependency change_pop i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_robots 	change_dependency change_pop ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg change_robots 	change_dependency change_pop if new_region=="OECD", r
estimates store e4

reg change_robots 	change_dependency change_pop $country_covariates  if new_region=="OECD", r
estimates store e5

reg change_robots 	change_dependency change_pop ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD", r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_change_pop_ols.tex", style(tex) ///
varlabels(change_pop     "\multirow{2}{6.5cm}{Change in population between 1990 and 2015}" ///
		  change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_pop) ///
order(change_dependency  change_pop)

*****************************************************************************************	
*****************Table A10, not reported: OLS models, weighted **************************
*****************************************************************************************

reg change_robots 	change_dependency change_pop i.dreg if full_sample $robot_weight, r
estimates store e1

reg change_robots 	change_dependency change_pop i.dreg $country_covariates if full_sample $robot_weight, r
estimates store e2

reg change_robots 	change_dependency change_pop ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r
estimates store e3

reg change_robots 	change_dependency change_pop if new_region=="OECD" $robot_weight, r
estimates store e4

reg change_robots 	change_dependency change_pop $country_covariates  if new_region=="OECD" $robot_weight, r
estimates store e5

reg change_robots 	change_dependency change_pop ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_change_pop_ols_weighted.tex", style(tex) ///
varlabels(change_pop     "\multirow{2}{6.5cm}{Change in population between 1990 and 2015}" ///
		  change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_pop) ///
order(change_dependency  change_pop)


*****************************************************************************************	
*****************Table A10, Panel B: IV models, unweighted ******************************
*****************************************************************************************

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop i.dreg if full_sample, r ffirst partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop i.dreg $country_covariates if full_sample, r ffirst partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r ffirst partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop if new_region=="OECD", r ffirst 
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop $country_covariates if new_region=="OECD", r ffirst 
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r ffirst 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_change_pop_iv.tex", style(tex) ///
varlabels(change_pop     "\multirow{2}{6.5cm}{Change in population between 1990 and 2015}" ///
		  change_dependency     "Aging between 1990 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_pop) ///
order(change_dependency  change_pop)

*****************************************************************************************	
*****************Table A10, not reported: IV models, weighted *****************************
*****************************************************************************************

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop i.dreg if full_sample $robot_weight, r ffirst partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop i.dreg $country_covariates if full_sample $robot_weight, r ffirst partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r ffirst partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop if new_region=="OECD" $robot_weight, r ffirst 
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop $country_covariates if new_region=="OECD" $robot_weight, r ffirst 
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments ) change_pop ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" $robot_weight, r ffirst 
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_change_pop_iv_weighted.tex", style(tex) ///
varlabels(change_pop     "\multirow{2}{6.5cm}{Change in population between 1990 and 2015}" ///
		  change_dependency     "Aging between 1990 and 2025"   ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_pop) ///
order(change_dependency  change_pop)

*****************************************************************************************	
*****************Table A10, Panel C: single IV models, unweighted ***********************
*****************************************************************************************

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_pop i.dreg if full_sample, r ffirst partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_pop i.dreg $country_covariates if full_sample, r ffirst partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_pop ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r ffirst partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_pop if new_region=="OECD", r ffirst 
estimates store e4

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_pop $country_covariates if new_region=="OECD", r ffirst 
estimates store e5

ivreg2 change_robots 	(change_dependency=change_birthrate_60_80 ) change_pop ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r ffirst 
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_change_pop_single_iv.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  change_pop     "\multirow{2}{6.5cm}{Change in population between 1990 and 2015}"   ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat."  )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_pop) ///
order(change_dependency  change_pop)



*****************************************************************************************	
*****************Table A10, Panel D: OLS models, unweighted *****************************
*****************Uses change in 65-year dependency ratio ********************************
*****************************************************************************************

reg change_robots 	change_dependency change_65 i.dreg if full_sample, r
estimates store e1

reg change_robots 	change_dependency change_65 i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_robots 	change_dependency change_65 ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg change_robots 	change_dependency change_65 if new_region=="OECD", r
estimates store e4

reg change_robots 	change_dependency change_65 $country_covariates  if new_region=="OECD", r
estimates store e5

reg change_robots 	change_dependency change_65 ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD", r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_change_65_ols.tex", style(tex) ///
varlabels(change_65     "\multirow{2}{6.5cm}{Change in 65-year dependency ratio 1990--2025}" ///
		  change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_65) ///
order(change_dependency  change_65)

*****************************************************************************************	
*****************Table A10, not reported: OLS models, weighted **************************
*****************Uses change in 65-year dependency ratio ********************************
*****************************************************************************************

reg change_robots 	change_dependency change_65 i.dreg if full_sample $robot_weight, r
estimates store e1

reg change_robots 	change_dependency change_65 i.dreg $country_covariates if full_sample $robot_weight, r
estimates store e2

reg change_robots 	change_dependency change_65 ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r
estimates store e3

reg change_robots 	change_dependency change_65 if new_region=="OECD" $robot_weight, r
estimates store e4

reg change_robots 	change_dependency change_65 $country_covariates  if new_region=="OECD" $robot_weight, r
estimates store e5

reg change_robots 	change_dependency change_65 ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_change_65_ols_weighted.tex", style(tex) ///
varlabels(change_65     "\multirow{2}{6.5cm}{Change in 65-year dependency ratio 1990--2025}" ///
		  change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_65) ///
order(change_dependency  change_65)
