/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A16: 	Robustness analysis of the impact of aging on
			imports and exports of robots
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_import_robust_full.tex
			/results/table_import_robust_oecd.tex
			/results/table_export_robust_full.tex
			/results/table_export_robust_oecd.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* programs to drop outliers *
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1, r
end

cap program drop ivreg_outliers
program define ivreg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: ivreg2 `y_vars' (`x_var'=$instruments) `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	ivreg2 `y_vars' (`x_var'=$instruments) `controls'  `wt'  if `cons_sample'==1, r
end


foreach sample in full oecd{
foreach flowtable in  ex im {

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear


* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1996_2015.dta", assert(1 3) nogenerate
merge 1:1 isocode using "${project}/clean_data/comtrade_robots_1996_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*compute total imports of intermediate goods*
foreach flow in im_ ex_ re_{
egen intermediate_`flow'96=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile), missing
}
 
*sample selection*
if "`flowtable'"=="im"{
*sample selection: drop japan---a large producer of robots*
drop if country_name=="japan" | country_name=="luxembourg"
local wts $imports_weights
}
else if "`flowtable'"=="ex" {
*sample selection: drop Nigeria---a large outlier*
drop if country_name=="nigeria"
local wts $exports_weights
}
if "`sample'"=="oecd"{
keep if new_region=="OECD"
}

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1995)

*regions*
encode new_region, gen(dreg)

* net imports and exports
gen net_imports_robots=tv_im_robots_orig-tv_re_robots_orig
gen net_exports_robots=tv_ex_robots_orig

drop if net_`flowtable'ports_robots<0

	************************
	*******Estimation*******
	************************ 

*outcome: share divided by total intermediate imports going back to 1996, the year that robot imports became available*
gen share=1000000*net_`flowtable'ports_robots/intermediate_`flowtable'_96 if net_`flowtable'ports_robots>=0
gen share_ln=ln(share)
gen ln_`flowtable'ports=ln(intermediate_`flowtable'_96)

***FULL SAMPLE***
*Baseline weighted*
reg share_ln  change_dependency ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg  `wts', r
estimates store e1 

ivreg2 share_ln  (change_dependency=$instruments) ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg  `wts', r
estimates store e2 

*log(1+x)*
gen share_full=ln(share+1)
reg share_full  change_dependency ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg  `wts', r
estimates store e3 

ivreg2 share_full  (change_dependency=$instruments ) ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg  `wts', r
estimates store e4

*Share*
sum share 
gen share_base=share/r(mean)
reg share_base  change_dependency ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg  `wts', r
estimates store e5 

ivreg2 share_base  (change_dependency=$instruments ) ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg  `wts', r
estimates store e6

*Remove outliers*
reg_outliers   share_ln  change_dependency   `wts',  control(ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg)
estimates store e7 

ivreg_outliers   share_ln  change_dependency   `wts',  control(ln_manuf_va ln_`flowtable'ports $country_covariates_1995   i.dreg)
estimates store e8 

estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table_`flowtable'port_robust_`sample'.tex", style(tex) ///
varlabels(change_dependency "Aging between 1995 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2 widstat jp, fmt(%7.0f %7.2f %7.1f %7.2f) labels("Observations" "R-squared"  "First-stage $ F$  stat." "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep( change_dependency ) ///
order(change_dependency ) 

}
}
