/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A21: 	Estimates of the impact of aging on robot
			installations per year

Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_flows_ols.tex
			/results/table_flows_iv.tex
			/results/table_flows_single_iv.tex
			/results/table_flows_ols_weighted.tex
			/results/table_flows_iv_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

* robotics variables *
merge 1:m isocode using "${project}/clean_data/country_robot_flows.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*Panel structure
encode country_name, gen(ccode)
xtset ccode year, delta(1)

*robots
sort ccode year
bysort ccode: gen base1993_stock_pc=stock_b19[1]/(${normalization_robots})
bysort ccode: gen flows_pc=investment_robots/(${normalization_robots})

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg flows_pc $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************ 

*****************************************************************************************	
*****************Table A21, Panel A: OLS models, unweighted *****************************
*****************************************************************************************

reg flows_pc    	change_dependency ib2014.year##i.dreg if full_sample==1, r  cluster(ccode)
estimates store e1

reg flows_pc    	change_dependency ib2014.year##i.dreg ib2014.year##c.($country_covariates) if full_sample==1, r  cluster(ccode)
estimates store e2

reg flows_pc    	change_dependency ib2014.year##i.dreg ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc) if full_sample==1, r  cluster(ccode)
estimates store e3

reg flows_pc    	change_dependency  if new_region=="OECD", r  cluster(ccode)
estimates store e4


reg flows_pc    	change_dependency  ib2014.year##c.($country_covariates) if new_region=="OECD", r  cluster(ccode)
estimates store e5


reg flows_pc    	change_dependency  ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc)  if new_region=="OECD", r  cluster(ccode)
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_flows_ols.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust r2, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)


*****************************************************************************************	
*****************Table A21, Panel B: IV models, unweighted ******************************
*****************************************************************************************

ivreg2 flows_pc    	(change_dependency=$instruments ) ib2014.year##i.dreg if full_sample==1, r  cluster(ccode) partial(ib2014.year##i.dreg) ffirst
estimates store e1

ivreg2 flows_pc    	(change_dependency=$instruments ) ib2014.year##i.dreg ib2014.year##c.($country_covariates) if full_sample==1, r  cluster(ccode)  partial(ib2014.year##i.dreg ib2014.year##c.($country_covariates))  ffirst
estimates store e2

ivreg2 flows_pc    	(change_dependency=$instruments ) ib2014.year##i.dreg ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc) if full_sample==1, r  cluster(ccode)  partial(ib2014.year##i.dreg ib2014.year##c.($country_covariates) ib2014.year#c.(ln_manuf_va  base1993_stock_pc))  ffirst
estimates store e3

ivreg2 flows_pc    	(change_dependency=$instruments )  if new_region=="OECD", r  cluster(ccode)  ffirst
estimates store e4

ivreg2 flows_pc    	(change_dependency=$instruments )  ib2014.year##c.($country_covariates) if new_region=="OECD", r  cluster(ccode) partial(ib2014.year##c.($country_covariates))   ffirst
estimates store e5

ivreg2 flows_pc    	(change_dependency=$instruments )  ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc)  if new_region=="OECD", r  cluster(ccode) partial(ib2014.year##c.($country_covariates) ib2014.year#c.(ln_manuf_va  base1993_stock_pc))  ffirst
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_flows_iv.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust widstat jp arfp, fmt(%7.0f %7.0f %7.1f %7.2f) labels("Observations" "Countries" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)


*****************************************************************************************	
***************Table A21, Panel C: single IV models, unweighted *************************
*****************************************************************************************

ivreg2 flows_pc    	(change_dependency=change_birthrate_60_80 ) ib2014.year##i.dreg if full_sample==1, r  cluster(ccode) partial(ib2014.year##i.dreg) 
estimates store e1

ivreg2 flows_pc    	(change_dependency=change_birthrate_60_80 ) ib2014.year##i.dreg ib2014.year##c.($country_covariates) if full_sample==1, r  cluster(ccode)  partial(ib2014.year##i.dreg ib2014.year##c.($country_covariates)) 
estimates store e2

ivreg2 flows_pc    	(change_dependency=change_birthrate_60_80 ) ib2014.year##i.dreg ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc) if full_sample==1, r  cluster(ccode)  partial(ib2014.year##i.dreg ib2014.year##c.($country_covariates) ib2014.year#c.(ln_manuf_va  base1993_stock_pc)) 
estimates store e3

ivreg2 flows_pc    	(change_dependency=change_birthrate_60_80 )  if new_region=="OECD", r  cluster(ccode) 
estimates store e4

ivreg2 flows_pc    	(change_dependency=change_birthrate_60_80 )  ib2014.year##c.($country_covariates) if new_region=="OECD", r  cluster(ccode) partial(ib2014.year##c.($country_covariates)) 
estimates store e5

ivreg2 flows_pc    	(change_dependency=change_birthrate_60_80 )  ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc)  if new_region=="OECD", r  cluster(ccode) partial(ib2014.year##c.($country_covariates) ib2014.year#c.(ln_manuf_va  base1993_stock_pc))
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_flows_single_iv.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust widstat, fmt(%7.0f %7.0f %7.1f ) labels("Observations" "Countries" "First-stage $ F$  stat." )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)


*****************************************************************************************	
*****************Table A21, Panel D: OLS models, weighted *******************************
*****************************************************************************************

reg flows_pc    	change_dependency ib2014.year##i.dreg if full_sample==1 $robot_weight, r  cluster(ccode)
estimates store e1

reg flows_pc    	change_dependency ib2014.year##i.dreg ib2014.year##c.($country_covariates) if full_sample==1 $robot_weight, r  cluster(ccode)
estimates store e2

reg flows_pc    	change_dependency ib2014.year##i.dreg ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc) if full_sample==1 $robot_weight, r  cluster(ccode)
estimates store e3

reg flows_pc    	change_dependency  if new_region=="OECD" $robot_weight, r  cluster(ccode)
estimates store e4


reg flows_pc    	change_dependency  ib2014.year##c.($country_covariates) if new_region=="OECD" $robot_weight, r  cluster(ccode)
estimates store e5


reg flows_pc    	change_dependency  ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc)  if new_region=="OECD" $robot_weight, r  cluster(ccode)
estimates store e6


*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_flows_ols_weighted.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust r2, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)


*****************************************************************************************	
*****************Table A21, Panel E: IV models, weighted ********************************
*****************************************************************************************

ivreg2 flows_pc    	(change_dependency=$instruments ) ib2014.year##i.dreg if full_sample==1 $robot_weight, r  cluster(ccode) partial(ib2014.year##i.dreg)  ffirst
estimates store e1

ivreg2 flows_pc    	(change_dependency=$instruments ) ib2014.year##i.dreg ib2014.year##c.($country_covariates) if full_sample==1 $robot_weight, r  cluster(ccode)  partial(ib2014.year##i.dreg ib2014.year##c.($country_covariates))  ffirst
estimates store e2

ivreg2 flows_pc    	(change_dependency=$instruments ) ib2014.year##i.dreg ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc) if full_sample==1 $robot_weight, r  cluster(ccode)  partial(ib2014.year##i.dreg ib2014.year##c.($country_covariates) ib2014.year#c.(ln_manuf_va  base1993_stock_pc))  ffirst
estimates store e3

ivreg2 flows_pc    	(change_dependency=$instruments )  if new_region=="OECD" $robot_weight, r  cluster(ccode)  ffirst
estimates store e4

ivreg2 flows_pc    	(change_dependency=$instruments )  ib2014.year##c.($country_covariates) if new_region=="OECD" $robot_weight, r  cluster(ccode) partial(ib2014.year##c.($country_covariates))   ffirst
estimates store e5

ivreg2 flows_pc    	(change_dependency=$instruments )  ib2014.year##c.($country_covariates ln_manuf_va  base1993_stock_pc)  if new_region=="OECD" $robot_weight, r  cluster(ccode) partial(ib2014.year##c.($country_covariates) ib2014.year#c.(ln_manuf_va  base1993_stock_pc)) ffirst
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_flows_iv_weighted.tex", style(tex) ///
varlabels(base1993_stock_pc     "Robots per thousand workers in 1993" ///
          change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust widstat jp arfp, fmt(%7.0f %7.0f %7.1f %7.2f ) labels("Observations" "Countries" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)
