/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Tables A24:	Estimates of the impact of aging on the log of one plus robot
			installations per worker in each country-industry cell
and A25:	Estimates of the impact of aging on robot installations by
			country-industry pair per year removing outliers
			
Notes: 		1. Sample excludes Pakistan and Macau, which have
			no industry-level data
			2. IV regressions for Tables A24 & A25 generate a warning
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_appendix_heterogeneity.tex
			/results/table_appendix_heterogeneity_iv.tex
			/results/table_outliers_heterogeneity.tex
			/results/table_outliers_heterogeneity_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* programs to drop outliers *
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric ts fv) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r cluster(cty_code)
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1,  r	cluster(cty_code)
end

cap program drop ivreg_outliers
program define ivreg_outliers, eclass 

syntax varlist(min=2 numeric ts fv) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: ivreg2 `y_vars' (`x_var'=$instruments c.($instruments )#c.(young_intensity prone_robots)) `controls'  `wt'  `if', r  cluster(cty_code)
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	ivreg2 `y_vars' (`x_var'=$instruments c.($instruments )#c.(young_intensity prone_robots)) `controls'  `wt'  if `cons_sample'==1,  r	cluster(cty_code) partial(`controls')

end

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

* determine sample of countries in Table 1 *
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg if country_name!= "japan" & country_name!="russian federation"
gen full_sample=e(sample)

* keep relevant covariates *
keep isocode full_sample ${aging_measure}* ${instruments} $industry_covariates_past dreg* ${normalization_robots}

* expand dataset *
expand 19
gen industry_ifr=""
bys isocode: replace industry_ifr="agriculture" if _n==1
bys isocode: replace industry_ifr="automotive" if _n==2
bys isocode: replace industry_ifr="construction" if _n==3
bys isocode: replace industry_ifr="education" if _n==4
bys isocode: replace industry_ifr="electronics" if _n==5
bys isocode: replace industry_ifr="food" if _n==6
bys isocode: replace industry_ifr="furniture" if _n==7
bys isocode: replace industry_ifr="glass" if _n==8
bys isocode: replace industry_ifr="man_other" if _n==9
bys isocode: replace industry_ifr="metal_basic" if _n==10
bys isocode: replace industry_ifr="metal_machinery" if _n==11
bys isocode: replace industry_ifr="metal_products" if _n==12
bys isocode: replace industry_ifr="mining" if _n==13
bys isocode: replace industry_ifr="nman_other" if _n==14
bys isocode: replace industry_ifr="paper" if _n==15
bys isocode: replace industry_ifr="plastic_chemicals" if _n==16
bys isocode: replace industry_ifr="textiles" if _n==17
bys isocode: replace industry_ifr="utilities" if _n==18
bys isocode: replace industry_ifr="vehicles_other" if _n==19
expand 23
bys isocode industry_ifr: gen year=_n+1992 

* robotics variables by industry * country * year *
merge 1:1 isocode industry_ifr year using "${project}/clean_data/country_industry_robot_flows.dta", assert(1 3) nogenerate

* klems and UNIDO variables by industry * country * year *
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_klems.dta", assert(1 3) nogenerate
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_unido.dta", assert(1 3) nogenerate

* merge industry characteristics *
merge m:1 industry_ifr using "${project}/clean_data/replaceability_ifr19.dta", assert(3) nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_1990", nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_2000", nogenerate
gen routine_bcg=0
replace routine_bcg=1 if industry_ifr=="automotive"
replace routine_bcg=1 if industry_ifr=="electronics"
replace routine_bcg=1 if industry_ifr=="metal_machinery"
replace routine_bcg=1 if industry_ifr=="plastic_chemicals"

* Panel structure *
encode isocode, gen(cty_code)
encode industry_ifr, gen(industry_code)
egen cell_code=group(isocode industry_ifr)
egen indyear_code=group(industry_ifr year)
xtset cell_code year
sort cell_code year

* normalizations: average industry employment *
gen emp_base=${normalization_robots}/19

*Interactions: evaluated at means *
gen young_intensity_raw=(1-share_55_emp_1990)/share_55_emp_1990
sum young_intensity_raw, d
gen young_intensity=young_intensity_raw-r(mean)

gen routine_intensity_rep=replaceable  
sum routine_intensity_rep, d
replace routine_intensity_rep=routine_intensity_rep-r(mean)

gen routine_intensity_bcg=routine_bcg
sum routine_intensity_bcg, d
replace routine_intensity_bcg=routine_intensity_bcg-r(mean)

*dependency
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
gen past_dependency=(${aging_measure}1990-${aging_measure}1950)

* baseline robot density * 
sort cell_code year
bysort cell_code: egen base_robots1993=total(stock_imputed*(year==1993))

* sample selection: Countries for which we observe some robot data and are in our baseline sample *
gen sample_all=(1-tag_noobs_flow)*tag_classified_flow*full_sample 

	************************
	*******Estimation*******
	************************ 

*log of one plus specification*
gen flows_pc=ln(investment_robots/emp_base+1)
				
*Imputed stocks for 1993*
bysort cell_code: gen indbase1993_stock_pc=ln(base_robots1993/emp_base+1)

*****************************************************************************************	
************Table A24, Panel A: OLS models **********************************************
*****************************************************************************************

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency   ///
					if sample_all==1 , r	cluster(cty_code)					
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code) 				
estimates store e2

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)						
estimates store e3

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* i.cty_code c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)				
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)				
estimates store e5

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)						
estimates store e6

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* i.cty_code c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1 , r	cluster(cty_code)					
estimates store e7

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_appendix_heterogeneity.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries in sample" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

*****************************************************************************************	
************Table A24, Panel B: IV models ***********************************************
*****************************************************************************************

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency=$instruments)   ///
					if sample_all==1, r	cluster(cty_code) partial(i.(year industry_code)##c.($industry_covariates ))	
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)  partial(c.($industry_covariates )##(ib2014.year i.industry_code))				
estimates store e2



ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* (change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code) indbase1993* )				
estimates store e3

					
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* i.cty_code (c.change_dependency#c.(young_intensity prone_robots)=c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)   partial(c.($industry_covariates )##(ib2014.year i.industry_code) i.cty_code indbase1993* )				
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))  ///
					if sample_all==1, r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code))				
estimates store e5

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* (change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code) indbase1993* ) 				
estimates store e6

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* i.cty_code (c.change_dependency#c.(young_intensity prone_robots)=c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)   partial(c.($industry_covariates )##(ib2014.year i.industry_code) i.cty_code indbase1993* )				
estimates store e7

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_appendix_heterogeneity_iv.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust  widstat jp, fmt(%7.0f %7.0f  %7.1f %7.2f) labels("Observations" "Countries in sample"  "Instruments F-stat" "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 


*****************************************************************************************	
************Table A25, Panel A: OLS models **********************************************
*****************************************************************************************


*specifications dropping outliers*
cap drop flows_pc indbase1993* 
gen flows_pc=investment_robots/emp_base
				
*Imputed stocks for 1993*
sort cell_code year
gen indbase1993_stock_pc=base_robots1993/emp_base

reg_outliers        flows_pc change_dependency if sample_all==1 , controls( (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
reg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots)  if sample_all==1 , controls((ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e2

reg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots)  if sample_all==1 , controls(indbase1993*   (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e3

reg_outliers        flows_pc c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls(i.cty_code indbase1993*   (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
reg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots)  if sample_all==1 , controls((ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e5

reg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls(indbase1993*   (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e6

reg_outliers        flows_pc c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls(i.cty_code indbase1993*   (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e7


*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_outliers_heterogeneity.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries in sample" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

*****************************************************************************************	
************Table A25, Panel B: IV models ***********************************************
*****************************************************************************************

ivreg_outliers        flows_pc change_dependency if sample_all==1 , controls( (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
ivreg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls( (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e2

ivreg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls(indbase1993*   (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e3

ivreg_outliers        flows_pc c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls(i.cty_code indbase1993*   (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
ivreg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls( (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e5

ivreg_outliers        flows_pc change_dependency c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls(indbase1993*  (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e6

ivreg_outliers        flows_pc c.change_dependency#c.(young_intensity prone_robots) if sample_all==1 , controls(i.cty_code indbase1993*  (ib2014.year i.industry_code)##c.($industry_covariates ) ) 
estimates store e7

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_outliers_heterogeneity_iv.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust  widstat jp, fmt(%7.0f %7.0f  %7.1f %7.2f) labels("Observations" "Countries in sample"  "Instruments F-stat" "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 
