/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Tables A26 and A27: Relationship between aging, education and gender
			        and specialization patterns/incentives 
					for robot adoption

Notes: 		Requested as part of the reviewing process

Revision:   Pascual Restrepo 1/29/2021
			
Output: 	/results/table_education.tex
			/results/table_education_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* program to compute partial and bivariate  R squares *
cap program drop decomp_ref
program define decomp_ref, eclass 

syntax varlist(min=1 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) AGE(varlist numeric ts fv) EDUC(varlist numeric ts fv) GENDER(varlist numeric ts fv)]
		
	* Create convenient weight local
	if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local y_var=word("`varlist'",1 )
	display "......................................"
	display "......Results for `y_var'......"
	display "......................................"
	
	quietly: ivreg2 `y_var' `age' `educ' `gender' `controls'  `wt'  `if', r partial(`educ' `gender' `controls')
	display "Partial R-square for age:" %9.2f e(r2c)
	
	quietly: ivreg2 `y_var' `age' `controls'  `wt'  `if', r partial(`controls')
	display "Bivariate R-square for age:" %9.2f e(r2c)
	
	quietly: ivreg2 `y_var' `age' `educ' `gender' `controls'  `wt'  `if', r partial(`age' `gender' `controls')
	display "Partial R-square for education:" %9.2f e(r2c)
	
	quietly: ivreg2 `y_var' `educ' `controls'  `wt'  `if', r partial(`controls')
	display "Bivariate R-square for education:" %9.2f e(r2c)
	
	quietly: ivreg2 `y_var' `age' `educ' `gender' `controls'  `wt'  `if', r partial(`age' `educ' `controls')
	display "Partial R-square for gender:" %9.2f e(r2c)
	
	quietly: ivreg2 `y_var' `gender' `controls'  `wt'  `if', r partial(`controls')
	display "Bivariate R-square for gender:" %9.2f e(r2c)
	
	
end


* * * * * * * Specialization patterns for the US (Table A26) * * * * * * * * * *

* exercise using us data *
use "${project}/clean_data/patterns1990.dta", clear
append using "${project}/clean_data/patterns2000.dta"
append using "${project}/clean_data/patterns2008.dta"

* blue-collar to white-collar ratio
gen rel_blue_job=blue_job/white_job

* census year
encode cy, gen(ccy)

*** full set of dummies ***
* share employed in robotizable industries *
decomp_ref rob_ind_job , controls(i.ccy) age(i.age_five) educ(i.education) gender(i.gender)

* relative employment in blue-collar jobs *
decomp_ref rel_blue_job , controls(i.ccy) age(i.age_five) educ(i.education) gender(i.gender)

*** simple cuttoffs ***
gen young=(age_five<=55)
gen nocollege=(education==2| education==3 | education==5)
gen men=(gender==1)

* share employed in robotizable industries *
decomp_ref rob_ind_job , controls(i.ccy) age(young) educ(nocollege) gender(men)

* relative employment in blue-collar jobs *
decomp_ref rel_blue_job , controls(i.ccy) age(young) educ(nocollege) gender(men)

* * * * * * * Specialization patterns for extended sample of countries (Table A26) * * * * * * * * * *

* exercise using pooled data from IPUMS international *
use "${project}/clean_data/specialization_ipums_international_long_education.dta", clear

encode educ, gen(education)
encode country_year, gen(ccy)
encode country, gen(ccode)
gen gender=sex

* weight countries by size/repetitions *
bys ccy: egen country_size=total(perwt)            
bys ccy: gen tag_unique=1 if _n==1
bys country: egen country_apps=total(tag_unique)
gen country_weight=country_size/country_apps
 
* relative employment in blue-collar jobs *
decomp_ref rel_ope_job [aw=country_weight], controls(i.ccy) age(i.age_five) educ(i.education) gender(i.gender)

* share employed in manufacturing--blue collar *
decomp_ref man_ope_job [aw=country_weight], controls(i.ccy) age(i.age_five) educ(i.education) gender(i.gender)

*** simple cuttoffs ***
gen young=(age_five<=55)
gen nocollege=(educ!="5-college")
gen men=(sex==1)

* relative employment in blue-collar jobs *
decomp_ref rel_ope_job [aw=country_weight], controls(i.ccy) age(young) educ(nocollege) gender(men)

* share employed in manufacturing--blue collar *
decomp_ref man_ope_job [aw=country_weight], controls(i.ccy) age(young) educ(nocollege) gender(men)


* * * * * * * Role of gender and education in driving robot adoption (Table A27) * * * * * * * * * *

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

* human capital and schooling *
gen change_hc  =(bl_all_full_college2010-bl_all_full_college1990)/100           /* change in human capital from BL dataset, 1990--2010 (note: no data after 2010) */
gen change_flfp=(flfp_prime2015-flfp_prime1990)/100                             /* change in relative female labor force participation, 1990--2015 */

*Unions: combine Rama dataset and ICTWSS*
gen union_density=rama_unions_85
replace union_density=ictwss_unions_90s if union_density==.
replace union_density=union_density/100

* sample selection: countries with robot data and full covariates, excluding Japan and Russia *
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates  i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

reg change_robots change_hc  i.dreg $country_covariates if full_sample, r
estimates store e1

reg change_robots change_flfp    i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_robots change_dep    i.dreg $country_covariates if full_sample, r
estimates store e3

reg change_robots change_hc change_flfp change_dep   i.dreg $country_covariates if full_sample, r
estimates store e4

reg change_robots change_hc    $country_covariates if new_region=="OECD", r
estimates store e5

reg change_robots change_flfp      $country_covariates if new_region=="OECD", r
estimates store e6

reg change_robots change_dep      $country_covariates if new_region=="OECD", r
estimates store e7

reg change_robots change_hc change_flfp change_dep     $country_covariates if new_region=="OECD", r
estimates store e8

decomp_ref change_robots  if full_sample, controls(i.dreg $country_covariates) age(change_dep) educ(change_hc) gender(change_flfp)
decomp_ref change_robots  if new_region=="OECD", controls(i.dreg $country_covariates) age(change_dep) educ(change_hc) gender(change_flfp)


* export table *
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_education.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  change_hc             "Increase in schooling 1990--2010" ///
		  change_flfp           "Change in relative FLFP 1990--2015") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_hc change_flfp) ///
order(change_hc change_flfp  change_dep)  
	
reg change_robots change_hc  i.dreg $country_covariates if full_sample $robot_weight , r
estimates store e1

reg change_robots change_flfp    i.dreg $country_covariates if full_sample $robot_weight , r
estimates store e2

reg change_robots change_dep    i.dreg $country_covariates if full_sample $robot_weight , r
estimates store e3

reg change_robots change_hc change_flfp change_dep   i.dreg $country_covariates if full_sample $robot_weight , r
estimates store e4

reg change_robots change_hc    $country_covariates if new_region=="OECD" $robot_weight , r
estimates store e5

reg change_robots change_flfp      $country_covariates if new_region=="OECD" $robot_weight , r
estimates store e6

reg change_robots change_dep      $country_covariates if new_region=="OECD" $robot_weight , r
estimates store e7

reg change_robots change_hc change_flfp change_dep     $country_covariates if new_region=="OECD" $robot_weight , r
estimates store e8

decomp_ref change_robots  if full_sample $robot_weight , controls(i.dreg $country_covariates) age(change_dep) educ(change_hc) gender(change_flfp)
decomp_ref change_robots  if new_region=="OECD" $robot_weight , controls(i.dreg $country_covariates) age(change_dep) educ(change_hc) gender(change_flfp)

* export table *
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_education_weighted.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  change_hc             "Increase in schooling 1990--2010" ///
		  change_flfp           "Change in relative FLFP 1990--2015") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency change_hc change_flfp) ///
order(change_hc change_flfp  change_dep) 



